@@ -50,7 +50,7 @@ gboolean singinggame_cross_click(TangleButton* tanglebutton, gpointer sequencer)
 	return FALSE;
 }
 
-void singinggame_add_cursor(ClutterColor* color, JammoSequencer* sequencer, ClutterActor* parent, gboolean seekable) {
+ClutterActor* singinggame_add_cursor(ClutterColor* color, JammoSequencer* sequencer, ClutterActor* parent, gboolean seekable) {
 	ClutterActor *container = tangle_widget_new();
 	ClutterActor* texture_color;
 	ClutterActor* texture_image;
@@ -89,6 +89,9 @@ void singinggame_add_cursor(ClutterColor* color, JammoSequencer* sequencer, Clut
 	clutter_actor_set_position(cursor, 0.0, 480.0-height-2);
 	clutter_actor_set_size(cursor, 800.0, height+4);
 	clutter_container_add_actor(CLUTTER_CONTAINER(parent), cursor);
+
+
+	return cursor;
 }
 
 
@@ -115,7 +118,7 @@ static void on_sequencer_stopped_playback(JammoSequencer* sequencer_old, gpointe
 
 	//Hide all
 	ClutterActor*	mainview = jammo_get_actor_by_id("main-views-widget"); //No drawing on stage anymore, use this.
-	clutter_container_foreach(CLUTTER_CONTAINER(mainview), chum_hide_this_tangle_actor, NULL);
+	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
 	
 	//Go back to songselection
 	ClutterActor* view = jammo_get_actor_by_id("songselection-view");
