@@ -12,6 +12,7 @@
 #include <tangle.h>
 #include <stdlib.h> //getenv(home)
 #include <fcntl.h> //we check some files
+#include <unistd.h>  //closing file
 
 
 #include "../../meam/jammo-backing-track.h"
@@ -19,6 +20,7 @@
 #include "../configure.h"  /*SONGS_DIR*/
 #include "../jammo-mentor.h"
 #include "../jammo-cursor.h"
+#include "../jammo-contour-area.h"
 #include "../jammo.h"
 
 #include "song.h"
@@ -27,77 +29,56 @@
 #include "chum.h"
 #include "gui.h"
 
+static ClutterActor* recording_cursor; //we want ask this location
+
 #ifdef MELODIC_CONTOUR
 static ClutterActor *contour_cursor;
-static ClutterActor *contour_trace;
+static ClutterActor *contour_trace_area;
 static ClutterActor *singinggame_display_freq;
 
 
-/*
-This will be more fancier some day.
-*/
-#define radius  5.0
-static void draw_trace(int x, int y) {
-	//offset: it looks like contour_star (png at this moment) is drawing line
-	cogl_path_ellipse (x+5, y+15, radius, radius);
-	cogl_path_stroke();
-}
-
-static void update_trace(ClutterActor *data,int x,int y){
-		//printf("update_texture called\n");
-		CoglHandle handle;
-		CoglHandle offscreen;
-
-		if ((handle = clutter_texture_get_cogl_texture(CLUTTER_TEXTURE(data))) == COGL_INVALID_HANDLE) 
-		{
-					handle = cogl_texture_new_with_size(800, 480, COGL_TEXTURE_NO_SLICING, COGL_PIXEL_FORMAT_RGBA_8888_PRE);
-					g_assert(handle != COGL_INVALID_HANDLE);
-					clutter_texture_set_cogl_texture(CLUTTER_TEXTURE(data), handle);
-		}
-
-		cogl_push_draw_buffer();
-		
-		/* TODO: the following memory allocation leaks even if there is unref. */
-		offscreen = cogl_offscreen_new_to_texture(handle);
-
-		g_assert(offscreen != COGL_INVALID_HANDLE);
-		cogl_set_draw_buffer(COGL_OFFSCREEN_BUFFER, offscreen);
-
-		cogl_set_source_color4f(1.0, 1.0, 0.1, 1.0);
-
-		draw_trace(x,y);
-		cogl_pop_draw_buffer();	
-		cogl_offscreen_unref(offscreen);
-
-		clutter_actor_queue_redraw(CLUTTER_ACTOR(data));
-}
 
 
-#define LEFT_MARGINAL 10      /*Marginal from left border.*/
-int contour_counter=LEFT_MARGINAL; /* This counts how many times cursor is moved*/
+
+
+
+
+
+
+
+
 /*
 FIXME we should handle x-axis with duration + current place of playback track.
 Now we just keep count how many signals are cathed.
 */
 static void on_pitch_detected(JammoRecordingTrack* track, gfloat frequency, gpointer user_data) {
 		g_return_if_fail(contour_cursor != NULL);
-		g_return_if_fail(contour_trace != NULL);
+		g_return_if_fail(contour_trace_area != NULL);
 
-		contour_counter+=1;
-		//int Y=(contour_counter-400)*(contour_counter-400)*0.001+100; //This is good for demo 
+		ClutterActor* texture_of_cursor;
+		g_object_get(recording_cursor, "texture", &texture_of_cursor,NULL);
+		gfloat X = clutter_actor_get_x(texture_of_cursor);
+		//int Y=(X-400)*(X-400)*0.001+100; //This is good for demo
 		int Y=840-(frequency*2); //frequence [220,480] -> place [480,0] //origo is on upper left corner
 
-		//if (contour_counter%10==0) //If it takes too much effort to draw it in each round.
-		update_trace(contour_trace,contour_counter,Y);
-		clutter_actor_set_position(contour_cursor,contour_counter,Y);
+		//Do not draw line over drawing area (it is very ugly)
+		if (Y<10)
+			Y=10;
+		if (Y>480-clutter_actor_get_height(texture_of_cursor)) //also if frequency is too low
+			Y=480-clutter_actor_get_height(texture_of_cursor);
+
+		//if (X%10==0) //If it takes too much effort to draw it in each round.
+		jammo_contour_area_trace_update(JAMMO_CONTOUR_AREA(contour_trace_area),X,Y);
+
+		clutter_actor_set_position(contour_cursor,X,Y);
+
 
-		
 		if (frequency==-1.0) /*This means, we do not have good value*/
-			clutter_text_set_text (CLUTTER_TEXT(singinggame_display_freq),"[ ∞ ]");
+			clutter_text_set_text (CLUTTER_TEXT(singinggame_display_freq),"DEBUG: Can't determine frequency");
 		else
 			{
 			gchar* buffer0;
-			buffer0 = g_strdup_printf("[%3.1lf]",frequency);
+			buffer0 = g_strdup_printf("DEBUG: frequency: [%3.1lf]",frequency);
 			clutter_text_set_text (CLUTTER_TEXT(singinggame_display_freq),buffer0);
 			g_free(buffer0);
 			}
@@ -213,7 +194,7 @@ static void on_sequencer_stopped_from_cupboard(JammoSequencer* sequencer_old, gp
 	printf("Sequencer '%p' stopped from cupboard\n", sequencer_old);
 	//Hide all
 	ClutterActor*	mainview = jammo_get_actor_by_id("main-views-widget");
-	clutter_container_foreach(CLUTTER_CONTAINER(mainview), chum_hide_this_tangle_actor, NULL);
+	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
 
 	//Show cupboard
 	ClutterActor* view = jammo_get_actor_by_id("cupboard-view");
@@ -382,34 +363,27 @@ static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 		clutter_container_add_actor (CLUTTER_CONTAINER (view), contour_cursor);
 
 
-		//contour_trace
-		contour_trace = g_object_new (CLUTTER_TYPE_TEXTURE, "disable-slicing", TRUE, NULL);
-
-		CoglHandle new_texture;
-		CoglTextureFlags flags = COGL_TEXTURE_NO_SLICING; //NO_SLICING is important.
-		new_texture = cogl_texture_new_with_size (WIDTH_OF_WINDOW,HEIGHT_OF_WINDOW,
-																								flags,
-																								COGL_PIXEL_FORMAT_RGBA_8888_PRE);
-
-		clutter_texture_set_cogl_texture (CLUTTER_TEXTURE(contour_trace), new_texture);
-		cogl_handle_unref (new_texture);
-
-		clutter_container_add_actor (CLUTTER_CONTAINER (view), contour_trace);
+		//contour_trace_area
+		contour_trace_area = jammo_contour_area_new ();
+		clutter_container_add_actor (CLUTTER_CONTAINER (view), contour_trace_area);
 
 
 		//And for debugging, text-field
-		singinggame_display_freq=  clutter_text_new_with_text ("Liberty","START"); //start with empty text
+		singinggame_display_freq=  clutter_text_new_with_text ("Liberty",""); //start with empty text
 		clutter_text_set_font_name(CLUTTER_TEXT(singinggame_display_freq),"Luxi Mono 18");
+		ClutterColor text_color = { 255, 255, 0, 255 };
+		clutter_text_set_color(CLUTTER_TEXT(singinggame_display_freq), &text_color);
+
 		clutter_container_add_actor (CLUTTER_CONTAINER (view), singinggame_display_freq);
 		clutter_actor_set_position (singinggame_display_freq, 100, 30);
 		clutter_actor_show (singinggame_display_freq);
 
 
+		recording_track = jammo_recording_track_new_with_pitch_detect(recording_filename);
+
 		//recording_track is from chum.c. on_pitch_detected uses only globals
 		g_signal_connect(recording_track, "pitch-detected", G_CALLBACK(on_pitch_detected), NULL);
 
-
-		recording_track = jammo_recording_track_new_with_pitch_detect(recording_filename);
 		#else /*MELODIC_CONTOUR */
 		recording_track = jammo_recording_track_new(recording_filename);
 		#endif  /*MELODIC_CONTOUR */
@@ -461,7 +435,7 @@ static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 		}
 
 	ClutterColor red = { 255, 0, 0, 128 };
-	singinggame_add_cursor(&red, sequencer, view, FALSE);
+	recording_cursor = singinggame_add_cursor(&red, sequencer, view, FALSE);
 
 	return FALSE;
 }
@@ -546,9 +520,7 @@ void song_prepare_icon(jammo_song* song){
 	song->y_size = y_size;
 
 	ClutterActor* texture = clutter_texture_new_from_file(image_filename, NULL);
-	ClutterActor* songbutton = tangle_button_new_with_background_actors(texture, texture);
-	clutter_actor_set_reactive(songbutton,TRUE);
-
+	ClutterActor* songbutton = tangle_button_new_with_background_actor(texture);
 	song->songbutton = songbutton;
 
 	g_signal_connect(songbutton, "clicked", G_CALLBACK (song_icon_clicked),song);
