@@ -662,17 +662,6 @@ if (use_two_tracks) y_offset=80;
 	ClutterActor *container_for_tracks = tangle_widget_new();
 
 
-	//Backing track
-	printf("backingtrack filename: '%s'\n",backing_track_filepath);
-	int fd = open(backing_track_filepath,O_RDONLY);
-	if (fd != -1) { //Found it.
-		JammoEditingTrack* backing_track = jammo_editing_track_new();
-		jammo_sequencer_add_track(sequencer, JAMMO_TRACK(backing_track));
-		jammo_editing_track_add_sample(backing_track, jammo_sample_new_from_file(backing_track_filepath), 0);
-		g_free(backing_track_filepath);
-	}
-
-
 	ClutterActor *container_for_backingtrack_blocks = tangle_widget_new();
 	clutter_actor_set_position(container_for_backingtrack_blocks, 0.0, 0.0);
 
@@ -692,9 +681,20 @@ if (use_two_tracks) y_offset=80;
 	guint64 big = temp * one_second;
 	guint64 slot_duration = big / beats_per_minute;
 
+	//Backing track
+	printf("backingtrack filename: '%s'\n",backing_track_filepath);
+	int fd = open(backing_track_filepath,O_RDONLY);
+	if (fd != -1) { //Found it.
+		JammoEditingTrack* backing_track = jammo_editing_track_new_fixed_duration(number_of_slots*slot_duration);
+		jammo_sequencer_add_track(sequencer, JAMMO_TRACK(backing_track));
+		jammo_editing_track_add_sample(backing_track, jammo_sample_new_from_file(backing_track_filepath), 0);
+		g_free(backing_track_filepath);
+	}
+
+
 
 	//Bottom track. Below of this there will be place for scrollbar.
-	JammoEditingTrack* editing_track_theme = jammo_editing_track_new();
+	JammoEditingTrack* editing_track_theme = jammo_editing_track_new_fixed_duration(number_of_slots*slot_duration);
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(editing_track_theme));
 	ClutterActor*	track_view = jammo_track_view_new(editing_track_theme, number_of_slots,slot_duration, WIDTH_OF_SLOT, 80.0);
 	g_object_set(track_view, "disabled-slots-begin", disabled_slots_for_begin, "disabled-slots-end", disabled_slots_for_end,NULL);
@@ -708,7 +708,7 @@ if (use_two_tracks) y_offset=80;
 
 	if (use_two_tracks){
 	//Upper track.
-	JammoEditingTrack* editing_track_theme2 = jammo_editing_track_new();
+	JammoEditingTrack* editing_track_theme2 = jammo_editing_track_new_fixed_duration(number_of_slots*slot_duration);
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(editing_track_theme2));
 	ClutterActor*	track_view2 = jammo_track_view_new(editing_track_theme2, number_of_slots,slot_duration, WIDTH_OF_SLOT, 80.0);
 	g_object_set(track_view2, "disabled-slots-begin", disabled_slots_for_begin, "disabled-slots-end", disabled_slots_for_end,NULL);
