@@ -15,7 +15,7 @@ And then sequencer_track_view_add_with_type(sequencerTrackViewTYpe)
 #include "../../meam/jammo-editing-track.h"
 #include "../../meam/jammo-instrument-track.h"
 #include "../../meam/jammo-midi.h"
-
+#include "../../meam/jammo-meam.h" //JAMMO_DURATION_INVALID
 
 #include "../jammo-track-view.h"
 #include "../jammo-miditrack-view.h"
@@ -28,22 +28,18 @@ And then sequencer_track_view_add_with_type(sequencerTrackViewTYpe)
 #include "midi_editor.h"
 #include "instrument_gui.h"
 
-//Some default values for track_views.
-//These works now e.g with animal/140/backing_track
-static int number_of_slots = 32;
-static guint64 one_second = 1000000000L;
-static int beats_per_minute = 140;
-static int tempo_factory = 4;
-
-static int width_of_slot = 40;
 
+//We get these as parameters
+static int number_of_slots = -1;
+static int width_of_slot = -1;
+static guint64 duration_of_tracks = JAMMO_DURATION_INVALID; //they all must have same duration
+static gfloat track_height = -1;
 
 
+static ClutterActor* texture_of_cursor;
 static SequencerTrackView *track_views[6] = {NULL};
 static gint tracks_in_use = 0;
 
-static ClutterActor* track_container = NULL; //contains all tracks (and nothing more) and will be in scroller_actor
-static ClutterActor *sequencer_track_area;   //all tracks and buttons and everything
 
 //All tracks share these
 static ClutterActor *TEXTURE_VOLUME_BACKGROUND;
@@ -136,23 +132,27 @@ static SequencerTrackView *sequencer_track_view_new(ClutterActor *label,
     ClutterActor *track_view, char *track_view_type, void* track) {
 
 	ClutterActor* mute_button = clutter_texture_new_from_file("/opt/jammo/sequencer/button_mute.png", NULL);
+	clutter_actor_set_size(mute_button, track_height-4,track_height-4); //it is square. Four pixels marginal
 	ClutterActor* volume_button = clutter_texture_new_from_file("/opt/jammo/sequencer/button_volume.png", NULL);
+	clutter_actor_set_size(volume_button, track_height-4,track_height-4); //it is square. Four pixels marginal
+
+	clutter_actor_set_height(label,track_height-4); //this is not square, so change oly height
 
 	SequencerTrackView *view = malloc(sizeof(SequencerTrackView));
-	view->sequencer_track_view_container = tangle_widget_new();
+	view->control_panel = tangle_widget_new();
 	view->label = label;
 	view->mute_button = mute_button;
 	view->volume_button = volume_button;
 	view->track_view = track_view;
-	view->position = -1;
-	view->muted = FALSE;
+	view->position = -1;   //This is used only for volume_slider: FIXME: remove
+	view->muted = FALSE;   //Track will know if it is muted. FIXME: remove
 	view->volume_pressed_down = FALSE;
-	view->volume_level = VOLUME_MAX;
+	view->volume_level = VOLUME_MAX;  //Track will know own volume_level. FIXME: remove
 	view->track_type = track_view_type;
 
-	tangle_widget_add(TANGLE_WIDGET(view->sequencer_track_view_container), view->label,NULL);
-	tangle_widget_add(TANGLE_WIDGET(view->sequencer_track_view_container), view->mute_button,NULL);
-	tangle_widget_add(TANGLE_WIDGET(view->sequencer_track_view_container), view->volume_button,NULL);
+	tangle_widget_add(TANGLE_WIDGET(view->control_panel), view->label,NULL);
+	tangle_widget_add(TANGLE_WIDGET(view->control_panel), view->mute_button,NULL);
+	tangle_widget_add(TANGLE_WIDGET(view->control_panel), view->volume_button,NULL);
 
 	gfloat x=0;
 	clutter_actor_set_position(view->label, x, 0.0);
@@ -179,20 +179,28 @@ static SequencerTrackView *sequencer_track_view_new(ClutterActor *label,
 /* Adds STV into array & container and positions it.
  */
 static void sequencer_track_view_add(SequencerTrackView *track_view) {
-	gfloat y_pos = 49.0;
-
 	track_views[tracks_in_use] = track_view;
-	tracks_in_use++;
-	clutter_container_add_actor(CLUTTER_CONTAINER(sequencer_track_area), track_view->sequencer_track_view_container);
 
+	//Add this tracks control_panel (volume buttons etc)
+	clutter_container_add_actor(CLUTTER_CONTAINER(jammo_get_actor_by_id("fullsequencer-track-control-panel")), track_view->control_panel);
+	clutter_actor_set_y(track_view->control_panel, track_height * tracks_in_use);
+
+	//Add track to container
+	ClutterActor* track_container = jammo_get_actor_by_id("fullsequencer-container-for-tracks");
 	clutter_container_add_actor(CLUTTER_CONTAINER(track_container), track_view->track_view);
 	clutter_actor_set_x(track_view->track_view, clutter_actor_get_x(track_view->track_view)+1);  //unless left border is not visible
-	clutter_actor_set_y(track_view->track_view, y_pos * (tracks_in_use - 1)+2);
+	clutter_actor_set_y(track_view->track_view, track_height * (tracks_in_use)+1);  //unless bottom border is not visible
 
-	clutter_actor_set_y(track_view->sequencer_track_view_container, y_pos * tracks_in_use);
-	track_view->position = tracks_in_use - 1;
+	//Raise container's and scroller's height
+	clutter_actor_set_height(track_container,clutter_actor_get_height(track_container)+track_height);
+	ClutterActor* scrolling_actor = jammo_get_actor_by_id("fullsequencer-scroller-for-tracks");
+	clutter_actor_set_height(scrolling_actor, clutter_actor_get_height(track_container));
+	clutter_actor_set_height(texture_of_cursor, clutter_actor_get_height(track_container));
+
+	track_view->position = tracks_in_use;
+	tracks_in_use++;
 	printf("Sequencer Track View placed in Position y: %f\n",
-         clutter_actor_get_y(track_view->sequencer_track_view_container));
+         clutter_actor_get_y(track_view->control_panel));
 }
 
 
@@ -202,17 +210,13 @@ static void sequencer_track_view_add(SequencerTrackView *track_view) {
  * Returns track_view_actor (jammo_track_view) of newly created sequencer_track_view
  * Returns NULL is askes invalid type.
  */
-ClutterActor* sequencer_track_view_add_with_type(gchar* track_view_type, guint64 duration) {
+ClutterActor* sequencer_track_view_add_with_type(gchar* track_view_type ) {
 	char *twt = track_view_type;
-	printf("Making '%s' track (duration: %" G_GUINT64_FORMAT ")\n",track_view_type, duration);
+	printf("Making '%s' track (duration: %" G_GUINT64_FORMAT ")\n",track_view_type, duration_of_tracks);
 
-	gfloat track_height = 50.0; //Maybe parameter?
+	guint64 duration_of_one_slot = duration_of_tracks / number_of_slots;
 
 	ClutterActor *label = clutter_texture_new();
-	guint64 temp=60*tempo_factory;
-	guint64 big = temp * one_second;
-	guint64 duration_of_one_slot = big / beats_per_minute;
-
 	JammoTrack* track;
 
 	ClutterActor* track_view_actor = NULL; //This will be returned
@@ -261,12 +265,16 @@ ClutterActor* sequencer_track_view_add_with_type(gchar* track_view_type, guint64
 	//Make editing_track and track_view
 	else
 	{
-		track = JAMMO_TRACK(jammo_editing_track_new_fixed_duration(duration));
+		track = JAMMO_TRACK(jammo_editing_track_new_fixed_duration(duration_of_tracks));
 
 		track_view_actor = jammo_track_view_new(JAMMO_EDITING_TRACK(track),
           number_of_slots, duration_of_one_slot, width_of_slot, track_height);
 		g_object_set(track_view_actor, "line-every-nth-slot", 1, NULL);
 	}
+	
+	/* TODO: This is a quick test. Please, fix me. */
+	ClutterColor sample_color = { 255, 255, 0, 255 };
+	g_object_set(track_view_actor, "sample-color", &sample_color, NULL);
 
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(track));
 	sequencer_track_view = sequencer_track_view_new(label, track_view_actor, twt, track);
@@ -314,7 +322,7 @@ static gboolean pressed_sequencer_button_track_label(ClutterActor *actor, Clutte
 		//TODO: some way to go straight to editor.
 
 		//jamming
-		instrument_gui_start(JAMMO_MIDITRACK_VIEW(track->track_view));
+		instrument_gui_start(JAMMO_MIDITRACK_VIEW(track->track_view),sequencer,FALSE); //slider=FALSE
 
 		//editor
 		//midi_editor_start_with_miditrack_view(JAMMO_MIDITRACK_VIEW(track->track_view));
@@ -385,7 +393,7 @@ static void set_volume_slider_position_by_state(gint state) {
 static void get_volume_background_coords(gfloat *position_x, gfloat *position_y) {
 
 	gfloat position_x_volume_background = clutter_actor_get_x(track_views[BUTTON_SEQUENCER_VOLUME_ACTIVE]->volume_button);
-	gfloat position_y_volume_background = clutter_actor_get_y(track_views[BUTTON_SEQUENCER_VOLUME_ACTIVE]->sequencer_track_view_container);
+	gfloat position_y_volume_background = clutter_actor_get_y(track_views[BUTTON_SEQUENCER_VOLUME_ACTIVE]->control_panel);
 	//get the width of volume button
 	gfloat volume_button_width = 0;
 	gfloat volume_button_height = 0;
@@ -611,9 +619,6 @@ void fullsequencer_metronome_clicked (TangleButton* tanglebutton, gpointer none)
 	}
 }
 
-void fullsequencer_trashbin_clicked (TangleButton* tanglebutton, gpointer none){
-	printf("fullsequencer: Trashbin pressed. Doesn't do anything\n");
-}
 
 void fullsequencer_community_clicked (TangleButton* tanglebutton, gpointer none){
 	printf("fullsequencer: Community pressed. Doesn't do anything\n");
@@ -632,35 +637,45 @@ void fullsequencer_home_clicked (TangleButton* tanglebutton, gpointer none){
 
 
 
+/*
+Will make container (TangleWidget) and put it inside scroller.
+Also prepare cursor.
+and make volumesliders FIXME. they are bugging!
+*/
+void sequencer_track_view_create_area_for_tracks(JammoSequencer* seq, guint n_slots, guint64 total_duration, gfloat slot_width, gfloat height) {
+	//Set statics
+	sequencer = seq;
+	number_of_slots = n_slots;
+	duration_of_tracks = total_duration;
+	width_of_slot = (int)slot_width;
+	track_height =  height; //track_height is slot_height
 
-ClutterActor *sequencer_track_view_create_area_for_tracks(JammoSequencer* seq) {
-
-	sequencer=seq;
-
-	//This is container we are making and will return
-	sequencer_track_area = tangle_widget_new();
 
 	gfloat width_of_area = number_of_slots*width_of_slot;
-	//Area for tracks (will be horizontally scrollable)
-	track_container = tangle_widget_new();
-	clutter_actor_set_size(track_container,width_of_area, 292.0);
 
-	ClutterActor* scrolling_actor;
-	scrolling_actor = tangle_scrolling_actor_new(track_container);
-	clutter_actor_set_position(scrolling_actor,  194.0, 48.0);
-	clutter_actor_set_size(scrolling_actor, 602.0, 295.0);
 
-	tangle_widget_add(TANGLE_WIDGET(sequencer_track_area),scrolling_actor,NULL);
+	ClutterActor* track_container = jammo_get_actor_by_id("fullsequencer-container-for-tracks");
+	//Tune width of track_container
+	//Height will be 0 and when track is added it will be raised
+	clutter_actor_set_size(track_container,width_of_area, 0.0);
+
+
+	ClutterActor* scrolling_actor = jammo_get_actor_by_id("fullsequencer-scroller-for-tracks");
+
+	//tune X-position of scroller
+	gfloat x_place_scroller=194.0; //TODO //width_of: label+mute_button+volume_slider
+	clutter_actor_set_x(scrolling_actor, x_place_scroller );
+	//Height will be 0 and when track is added it will be raised
+	clutter_actor_set_size(scrolling_actor, 800-x_place_scroller, 0.0);
 
 
 	//Cursor:
 	ClutterColor red = { 255, 0, 0, 128 };
-	ClutterActor* texture;
 	ClutterActor* cursor;
 
-	texture = clutter_rectangle_new_with_color(&red);
-	clutter_actor_set_size(texture, 10.0, 292.0 ); //TODO, change height this depending number of tracks
-	cursor = jammo_cursor_new(sequencer, texture);
+	texture_of_cursor = clutter_rectangle_new_with_color(&red); //this is static, because we want change it's height
+	clutter_actor_set_size(texture_of_cursor, 10.0, 0.0 );
+	cursor = jammo_cursor_new(sequencer, texture_of_cursor);
 	tangle_actor_set_depth_position(TANGLE_ACTOR(cursor), 1);
 	clutter_actor_set_position(cursor, 0.0, 0.0);
 	clutter_actor_set_size(cursor, width_of_area, 80.0);
@@ -670,9 +685,11 @@ ClutterActor *sequencer_track_view_create_area_for_tracks(JammoSequencer* seq) {
 	TangleVault* vault;
 
 	vault = tangle_vault_new(2, TANGLE_TYPE_SCROLLING_ACTOR, scrolling_actor, JAMMO_TYPE_CURSOR, cursor);
-	tangle_signal_connect_vault(texture, "notify::x", G_CALLBACK(on_cursor_notify_x), vault);
+	tangle_signal_connect_vault(texture_of_cursor, "notify::x", G_CALLBACK(on_cursor_notify_x), vault);
 
 
+
+	//FIXME: use TangleScrollingActor
 	TEXTURE_VOLUME_BACKGROUND = clutter_texture_new_from_file("/opt/jammo/sequencer/volume_background.png", NULL);
 	BUTTON_VOLUME_SLIDER =clutter_texture_new_from_file("/opt/jammo/sequencer/volume_button.png", NULL);
 
@@ -688,10 +705,10 @@ ClutterActor *sequencer_track_view_create_area_for_tracks(JammoSequencer* seq) {
 	clutter_actor_set_reactive(TEXTURE_VOLUME_BACKGROUND, TRUE);
 	clutter_actor_set_reactive(BUTTON_VOLUME_SLIDER, TRUE);
 
+	ClutterActor* sequencer_track_area = jammo_get_actor_by_id("fullsequencer-track-control-panel");
 	tangle_widget_add(TANGLE_WIDGET(sequencer_track_area),TEXTURE_VOLUME_BACKGROUND,NULL);
 	tangle_widget_add(TANGLE_WIDGET(sequencer_track_area),BUTTON_VOLUME_SLIDER,NULL);
 
 	clutter_actor_hide(TEXTURE_VOLUME_BACKGROUND);
 	clutter_actor_hide(BUTTON_VOLUME_SLIDER);
-	return sequencer_track_area;
 }
