@@ -1093,7 +1093,7 @@ void jammo_collaboration_jamming_on_sequencer_stopped_recording(JammoSequencer*
 	if (collaboration_jamming->priv->jamming_state==JAMMINGSTATE_GENERATING_MIX) {
 		collaboration_jamming->priv->jamming_state=JAMMINGSTATE_DONE_GENERATING;
 	}
-	else if (collaboration_jamming->priv->jamming_state==JAMMINGSTATE_ERROR) {
+	else if (collaboration_jamming->priv->jamming_state==JAMMINGSTATE_INIT || collaboration_jamming->priv->jamming_state==JAMMINGSTATE_ERROR) {
 		;
 	}
 	else {
