@@ -16,7 +16,7 @@ G_DEFINE_TYPE(JammoCollaborationPairComposition, jammo_collaboration_pair_compos
 #include "../meam/jammo-sequencer.h"
 #include "../meam/jammo-backing-track.h"
 #include "../chum/jammo-track-view.h"
-
+#include "../meam/jammo-loop.h"
 #include "../gems/gems_definitions.h"
 #include "../gems/groupmanager.h"
 #include "../gems/gems.h"
@@ -62,6 +62,23 @@ static void jammo_collaboration_pair_composition_remove_jammo_sample_button_remo
 	jammo_track_view_remove_jammo_sample_button_from_slot(collaboration_pair_composition->priv->peer_track_view, slot);
 }
 
+static void jammo_collaboration_pair_composition_loop_sync_remote(GObject * game, guint32 user_id, GList * list) {
+	GList* temp;
+	JammoLoop* n;
+
+	// TODO clear existing sample buttons
+
+	//TODO: loop_id --> sample_button
+
+	//TODO: add loops
+	printf("jammo-collaboration-pair-composition loop sync stub, user id %u\n", user_id);
+  printf("Loop list:\n");
+	for (temp = list; temp; temp = temp->next) {
+		n = (temp->data);
+		printf("  loop_id %u, slot %u\n", n->loop_id,n->slot);
+	}
+}
+
 
 static void jammo_collaboration_pair_composition_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
 	JammoCollaborationPairComposition * collaboration_pair_composition;
@@ -90,6 +107,7 @@ static void jammo_collaboration_pair_composition_set_property(GObject* object, g
 				//Callback for multiplaying
 				gems_set_callback_add_loop(jammo_collaboration_pair_composition_add_jammo_sample_button_remote);
 				gems_set_callback_remove_loop(jammo_collaboration_pair_composition_remove_jammo_sample_button_remote);
+				gems_set_callback_loop_sync(jammo_collaboration_pair_composition_loop_sync_remote);
 			}
 			else {
 				collaboration_pair_composition->priv->peer_track_view = NULL;
@@ -201,6 +219,13 @@ static void jammo_collaboration_pair_composition_init(JammoCollaborationPairComp
 	collaboration_pair_composition->priv = G_TYPE_INSTANCE_GET_PRIVATE(collaboration_pair_composition, JAMMO_TYPE_COLLABORATION_PAIR_COMPOSITION, JammoCollaborationPairCompositionPrivate);
 }
 
+void jammo_collaboration_pair_composition_loop_sync (JammoCollaborationPairComposition * group_composition) {
+	// TODO get own loops from view and send them
+	GList * list =NULL;
+	gems_loop_sync(list);
+	jammo_loop_free_glist(&list);
+}
+
 // function prototypes
 void jammo_collaboration_pair_composition_on_sequencer_stopped_recording(JammoSequencer* sequencer, gpointer data);
 int create_mix_of_pair_composition(gpointer data);
@@ -258,7 +283,7 @@ void exit_pair_composition(JammoCollaborationPairComposition * collaboration_pai
 	clean_up(collaboration_pair_composition);
 }
 
-int jammo_collaboration_pair_composition_start(JammoCollaborationPairComposition * collaboration_pair_composition, gboolean host) {
+int jammo_collaboration_pair_composition_start(JammoCollaborationPairComposition * collaboration_pair_composition, gboolean host, guint32 join_group_id, guint32 group_owner_id) {
 
 	// this is how to add callback functions to main loop
 	/*g_timeout_add_full(G_PRIORITY_DEFAULT,100,(GSourceFunc)create_mix_of_pair_composition,collaboration_pair_composition,NULL);*/
@@ -275,16 +300,8 @@ int jammo_collaboration_pair_composition_start(JammoCollaborationPairComposition
 
 	else {
 		printf("***CLIENT\n");
-		// Returns a copy of the group list
-		GList* list =gems_group_list_other_groups();
-		printf("length %d\n",g_list_length(list));
-		GList* l;
-		for (l=list;l;l=l->next) {
-		
-			gems_group_join_to_group( ((gems_group_info*)(l->data))->id);
-			collaboration_pair_composition->priv->peer_user_id = ((gems_group_info*)(l->data))->owner;
-		}
-		g_list_free(list); // Free the copy of the list
+		gems_group_join_to_group(join_group_id);
+		collaboration_pair_composition->priv->peer_user_id = group_owner_id;
 	}
 
 	// set pair composition to gems
