@@ -249,11 +249,7 @@ static gboolean on_button_press_event(ClutterActor* actor, ClutterEvent* event,
 	cursor->priv->motion_event_handler_id = g_signal_connect(clutter_actor_get_stage(actor), "motion-event", G_CALLBACK(on_motion_event), cursor);
 	cursor->priv->button_release_event_handler_id = g_signal_connect(clutter_actor_get_stage(actor), "button-release-event", G_CALLBACK(on_button_release_event), cursor);
 	
-	tangle_event = tangle_event_new(TANGLE_EVENT_INTERACTION_BEGAN, TANGLE_ACTOR(cursor));
-	tangle_event->interaction.x_axis = TRUE;
-	tangle_event->interaction.y_axis = TRUE;
-	tangle_actor_send_event(TANGLE_ACTOR(cursor), tangle_event);
-	tangle_event_free(tangle_event);
+	tangle_actor_send_interaction_began_event(TANGLE_ACTOR(cursor), TRUE, TRUE, TRUE);
 
 	return FALSE;
 }
@@ -288,6 +284,8 @@ static gboolean on_button_release_event(ClutterActor* actor, ClutterEvent* event
 	jammo_sequencer_set_position(cursor->priv->sequencer, jammo_sequencer_get_duration(cursor->priv->sequencer) * fraction);
 	
 	if (cursor->priv->motion_event_handler_id) {
+		tangle_actor_send_interaction_ended_event(TANGLE_ACTOR(cursor), TRUE, TRUE, TRUE);
+
 		g_signal_handler_disconnect(actor, cursor->priv->motion_event_handler_id);
 		g_signal_handler_disconnect(actor, cursor->priv->button_release_event_handler_id);
 		cursor->priv->motion_event_handler_id = cursor->priv->button_release_event_handler_id = 0;
