@@ -18,15 +18,38 @@ enum {
 	PROP_0,
 	PROP_IMAGE_FILENAME,
 	PROP_SAMPLE_FILENAME,
-	PROP_SAMPLE
+	PROP_SAMPLE,
+	PROP_SAMPLE_TYPE,
+	PROP_TEXT
 };
 
 struct _JammoSampleButtonPrivate {
 	gchar* image_filename;
 	JammoSample* sample;
+	JammoSampleType sample_type;
 };
 
+static const GEnumValue sample_type_values[] = {
+	{ JAMMO_SAMPLE_UNTYPED, "JAMMO_SAMPLE_UNTYPED", "untyped" },
+	{ JAMMO_SAMPLE_RHYTMICAL, "JAMMO_SAMPLE_RHYTHMICAL", "rhytmical" },
+	{ JAMMO_SAMPLE_MELODICAL, "JAMMO_SAMPLE_MELODICAL", "melodical" },
+	{ JAMMO_SAMPLE_HARMONICAL, "JAMMO_SAMPLE_HARMONICAL", "harmonical" },
+	{ JAMMO_SAMPLE_EFFECT, "JAMMO_SAMPLE_EFFECT", "effect" },
+	{ 0, NULL, NULL }
+};
+
+GType jammo_sample_type_get_type(void) {
+	static GType type = 0;
+	
+	if (!type) {
+		type = g_enum_register_static("JammoSampleType", sample_type_values);
+	}
+	
+	return type;
+}
+
 static gboolean on_clicked(TangleButton* button, gpointer user_data);
+static void on_size_change(ClutterTexture* texture, gint width, gint height, gpointer user_data);
 
 ClutterActor* jammo_sample_button_new() {
 
@@ -38,6 +61,16 @@ ClutterActor* jammo_sample_button_new_from_files(const gchar* image_filename, co
 	return CLUTTER_ACTOR(g_object_new(JAMMO_TYPE_SAMPLE_BUTTON, "image-filename", image_filename, "sample-filename", sample_filename, NULL));
 }
 
+ClutterActor* jammo_sample_button_new_with_type(JammoSampleType sample_type) {
+
+	return CLUTTER_ACTOR(g_object_new(JAMMO_TYPE_SAMPLE_BUTTON, "sample-type", sample_type, NULL));
+}
+
+ClutterActor* jammo_sample_button_new_with_type_from_files(JammoSampleType sample_type, const gchar* image_filename, const gchar* sample_filename) {
+
+	return CLUTTER_ACTOR(g_object_new(JAMMO_TYPE_SAMPLE_BUTTON, "sample-type", sample_type, "image-filename", image_filename, "sample-filename", sample_filename, NULL));
+}
+
 ClutterActor* jammo_sample_button_new_from_existing(JammoSampleButton* sample_button) {
 
 	return CLUTTER_ACTOR(g_object_new(JAMMO_TYPE_SAMPLE_BUTTON, "image-filename", sample_button->priv->image_filename, "sample", sample_button->priv->sample, NULL));
@@ -59,13 +92,16 @@ JammoSample* jammo_sample_button_get_sample(JammoSampleButton* sample_button) {
 }
 
 void jammo_sample_button_set_image_filename(JammoSampleButton* sample_button, const gchar* image_filename) {
+	ClutterActor* texture;
+	
 	if (!sample_button->priv->image_filename ||
 	    strcmp(sample_button->priv->image_filename, image_filename)) {
 		g_free(sample_button->priv->image_filename);
 		sample_button->priv->image_filename = g_strdup(image_filename);
 
-		tangle_button_set_normal_background_actor(TANGLE_BUTTON(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(sample_button))),
-		                                          clutter_texture_new_from_file(image_filename, NULL));
+		texture = clutter_texture_new_from_file(image_filename, NULL);
+		tangle_button_set_normal_background_actor(TANGLE_BUTTON(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(sample_button))), texture);
+		g_signal_connect(texture, "size-change", G_CALLBACK(on_size_change), sample_button);
 
 		g_object_notify(G_OBJECT(sample_button), "image-filename");
 	}
@@ -100,6 +136,66 @@ void jammo_sample_button_set_sample(JammoSampleButton* sample_button, JammoSampl
 	}
 }
 
+JammoSampleType jammo_sample_button_get_sample_type(JammoSampleButton* sample_button) {
+
+	return sample_button->priv->sample_type;
+}
+
+void jammo_sample_button_set_sample_type(JammoSampleButton* sample_button, JammoSampleType sample_type) {
+	if (sample_button->priv->sample_type != sample_type) {
+		sample_button->priv->sample_type = sample_type;
+		g_object_notify(G_OBJECT(sample_button), "sample-type");
+	}
+}
+
+void jammo_sample_button_get_background_color(JammoSampleButton* sample_button, ClutterColor* background_color) {
+	tangle_widget_get_background_color(TANGLE_WIDGET(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(sample_button))), background_color);
+}
+
+gboolean jammo_sample_button_get_background_color_set(JammoSampleButton* sample_button) {
+
+	return tangle_widget_get_background_color_set(TANGLE_WIDGET(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(sample_button))));
+}
+
+void jammo_sample_button_set_background_color(JammoSampleButton* sample_button, const ClutterColor* background_color) {
+	tangle_widget_set_background_color(TANGLE_WIDGET(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(sample_button))), background_color);
+}
+
+const gchar* jammo_sample_button_get_text(JammoSampleButton* sample_button) {
+	const gchar* text = NULL;
+	ClutterActor* actor;
+	
+	if ((actor = tangle_widget_get_foreground_actor(TANGLE_WIDGET(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(sample_button))))) &&
+	    CLUTTER_IS_TEXT(actor)) {
+		text = clutter_text_get_text(CLUTTER_TEXT(actor));
+	}
+	
+	return text;
+}
+	
+void jammo_sample_button_set_text(JammoSampleButton* sample_button, const gchar* text) {
+	TangleWidget* widget;
+	ClutterActor* actor;
+
+	widget = TANGLE_WIDGET(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(sample_button)));
+	if ((actor = tangle_widget_get_foreground_actor(widget))) {
+		g_return_if_fail(CLUTTER_IS_TEXT(actor));
+		
+		if (g_strcmp0(clutter_text_get_text(CLUTTER_TEXT(actor)), text)) {
+			if (text) {
+				clutter_text_set_text(CLUTTER_TEXT(actor), text);
+				g_object_notify(G_OBJECT(sample_button), "text");
+			} else {
+				tangle_widget_set_foreground_actor(widget, NULL);
+				g_object_notify(G_OBJECT(sample_button), "text");
+			}
+		}
+	} else if (text) {
+		tangle_widget_set_foreground_actor(widget, clutter_text_new_with_text("Sans 12", text));
+		g_object_notify(G_OBJECT(sample_button), "text");
+	}
+}
+
 static gboolean jammo_sample_button_end_dragging(TangleDraggableActor* draggable_actor, TangleDragging* dragging) {
 	gboolean retvalue = FALSE;
 	JammoSampleButton* sample_button;
@@ -148,6 +244,12 @@ static void jammo_sample_button_set_property(GObject* object, guint prop_id, con
 		case PROP_SAMPLE:
 			jammo_sample_button_set_sample(sample_button, JAMMO_SAMPLE(g_value_get_object(value)));
 			break;
+		case PROP_SAMPLE_TYPE:
+			sample_button->priv->sample_type = g_value_get_enum(value);
+			break;
+		case PROP_TEXT:
+			jammo_sample_button_set_text(sample_button, g_value_get_string(value));
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 			break;
@@ -169,6 +271,12 @@ static void jammo_sample_button_get_property(GObject* object, guint prop_id, GVa
 		case PROP_SAMPLE:
 			g_value_set_object(value, jammo_sample_button_get_sample(sample_button));
 			break;
+		case PROP_SAMPLE_TYPE:
+			g_value_set_enum(value, sample_button->priv->sample_type);
+			break;
+		case PROP_TEXT:
+			g_value_set_string(value, jammo_sample_button_get_text(sample_button));
+			break;
 		default:
 		        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		        break;
@@ -204,7 +312,6 @@ static void jammo_sample_button_class_init(JammoSampleButtonClass* sample_button
 	                                "The filename of the displayed image",
 					NULL,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
-
 	/**
 	 * JammoSampleButton:sample-filename:
 	 */
@@ -214,7 +321,6 @@ static void jammo_sample_button_class_init(JammoSampleButtonClass* sample_button
 	                                "The filename of the played sample",
 					NULL,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
-
 	/**
 	 * JammoSampleButton:sample:
 	 */
@@ -224,6 +330,28 @@ static void jammo_sample_button_class_init(JammoSampleButtonClass* sample_button
 	                                "The JammoSample that is played when the button is interacting",
 	                                JAMMO_TYPE_SAMPLE,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	/**
+	 * JammoSampleButton:sample-type:
+	 *
+	 * The type of the sample (not used internally).
+	 */
+	g_object_class_install_property(gobject_class, PROP_SAMPLE_TYPE,
+	                                g_param_spec_enum("sample-type",
+	                                "Sample type",
+	                                "The type of the sample (not used internally)",
+	                                JAMMO_TYPE_SAMPLE_TYPE, JAMMO_SAMPLE_UNTYPED,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	/**
+	 * JammoSampleButton:text:
+	 *
+	 * A text that is displayed on top of the button.
+	 */
+	g_object_class_install_property(gobject_class, PROP_TEXT,
+	                                g_param_spec_string("text",
+	                                "Text",
+	                                "A text that is displayed on top of the button",
+	                                NULL,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 
 	g_type_class_add_private(gobject_class, sizeof(JammoSampleButtonPrivate));
 }
@@ -232,8 +360,6 @@ static void jammo_sample_button_init(JammoSampleButton* sample_button) {
 	sample_button->priv = G_TYPE_INSTANCE_GET_PRIVATE(sample_button, JAMMO_TYPE_SAMPLE_BUTTON, JammoSampleButtonPrivate);
 }
 
-
-
 static gboolean on_clicked(TangleButton* button, gpointer user_data) {
 	JammoSampleButton* sample_button;
 	
@@ -245,3 +371,10 @@ static gboolean on_clicked(TangleButton* button, gpointer user_data) {
 	return FALSE;
 }
 
+static void on_size_change(ClutterTexture* texture, gint width, gint height, gpointer user_data) {
+	JammoSampleButton* sample_button;
+	
+	sample_button = JAMMO_SAMPLE_BUTTON(user_data);
+	
+	tangle_actor_set_aspect_ratio(TANGLE_ACTOR(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(sample_button))), width / height);
+}
