@@ -20,6 +20,8 @@
 #define JAMMO_IS_SAMPLE_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), JAMMO_TYPE_SAMPLE_BUTTON))
 #define JAMMO_SAMPLE_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), JAMMO_TYPE_SAMPLE_BUTTON, JammoSampleButtonClass))
 
+#define JAMMO_TYPE_SAMPLE_TYPE (jammo_sample_type_get_type())
+
 typedef struct _JammoSampleButtonPrivate JammoSampleButtonPrivate;
 
 typedef struct _JammoSampleButton {
@@ -33,10 +35,22 @@ typedef struct _JammoSampleButtonClass {
 
 GType jammo_sample_button_get_type(void) G_GNUC_CONST;
 
+typedef enum _JammoSampleType {
+	JAMMO_SAMPLE_UNTYPED = 0,
+	JAMMO_SAMPLE_RHYTMICAL,
+	JAMMO_SAMPLE_MELODICAL,
+	JAMMO_SAMPLE_HARMONICAL,
+	JAMMO_SAMPLE_EFFECT
+} JammoSampleType;
+
+GType jammo_sample_type_get_type(void) G_GNUC_CONST;
+
 #include "../meam/jammo-sample.h"
 
 ClutterActor* jammo_sample_button_new();
 ClutterActor* jammo_sample_button_new_from_files(const gchar* image_filename, const gchar* sample_filename);
+ClutterActor* jammo_sample_button_new_with_type(JammoSampleType sample_type);
+ClutterActor* jammo_sample_button_new_with_type_from_files(JammoSampleType sample_type, const gchar* image_filename, const gchar* sample_filename);
 ClutterActor* jammo_sample_button_new_from_existing(JammoSampleButton* sample_button);
 const gchar* jammo_sample_button_get_image_filename(JammoSampleButton* sample_button);
 const gchar* jammo_sample_button_get_sample_filename(JammoSampleButton* sample_button);
@@ -44,5 +58,12 @@ JammoSample* jammo_sample_button_get_sample(JammoSampleButton* sample_button);
 void jammo_sample_button_set_image_filename(JammoSampleButton* sample_button, const gchar* image_filename);
 void jammo_sample_button_set_sample_filename(JammoSampleButton* sample_button, const gchar* sample_filename);
 void jammo_sample_button_set_sample(JammoSampleButton* sample_button, JammoSample* sample);
+JammoSampleType jammo_sample_button_get_sample_type(JammoSampleButton* sample_button);
+void jammo_sample_button_set_sample_type(JammoSampleButton* sample_button, JammoSampleType sample_type);
+void jammo_sample_button_get_background_color(JammoSampleButton* sample_button, ClutterColor* background_color);
+gboolean jammo_sample_button_get_background_color_set(JammoSampleButton* sample_button);
+void jammo_sample_button_set_background_color(JammoSampleButton* sample_button, const ClutterColor* background_color);
+const gchar* jammo_sample_button_get_text(JammoSampleButton* sample_button);
+void jammo_sample_button_set_text(JammoSampleButton* sample_button, const gchar* text);
 
 #endif
