@@ -26,6 +26,8 @@
 #include "groupmanager.h"
 #include "../cem/cem.h"
 #include "gems_service_collaboration.h"
+#include "gems_service_control.h"
+#include "collaboration.h"
 
 #define SOCKET_ERROR        -1
 #define HOST_NAME_SIZE      255
@@ -35,302 +37,6 @@
 
 GTimer* testtimer;
 
-/*int connected=0;
-int hServerSocket; //Listening socket
-
-//FDSet stuff for select(serverthread)
-fd_set master;    // master file descriptor list
-fd_set read_fds;  // temp file descriptor list for select()
-int fdmax;        // maximum file descriptor number
-int noconnections;
-struct connection* connectionlist;
-int serverrunning=0;*/
-
-void * serverthread(void *);
-
-int communication_create_connection(char *address, int port, ip_communication* communicationdata)
-{
-	struct hostent* pHostInfo;   /* holds info about a machine */
-	struct sockaddr_in Address;  /* Internet socket address stuct */
-	char buffer[100];
-    	long nHostAddress;
-	char strHostName[HOST_NAME_SIZE];
-	int rc;
-    	pthread_t threadid;
-
-	if(strlen(address)<HOST_NAME_SIZE)
-	{
-		strcpy(strHostName,address);
-	}
-     	else
-	{
-		printf("\nHost name too long\n");
-		return -1;
-	}
-	
-	communicationdata->connectionlist = (struct connection *)realloc(communicationdata->connectionlist, (communicationdata->noconnections +1) * sizeof(struct connection));
-
-	communicationdata->connectionlist[communicationdata->noconnections].userid=communicationdata->noconnections;
-	
-	FD_ZERO(&communicationdata->master);    // clear the master and temp sets
-    	FD_ZERO(&communicationdata->read_fds);
-
-    	printf("\nMaking a socket");
-    	/* make a socket */
-    	communicationdata->connectionlist[communicationdata->noconnections].sockethandle=socket(AF_INET,SOCK_STREAM,IPPROTO_TCP);
-
-    	if(communicationdata->connectionlist[communicationdata->noconnections].sockethandle == SOCKET_ERROR)
-    	{
-        	printf("\nCould not make a socket\n");
-        	return 0;
-    	}
-
-
-    	/* get IP address from name */
-    	pHostInfo=gethostbyname(strHostName);
-   	/* copy address into long */
-    	memcpy(&nHostAddress,pHostInfo->h_addr,pHostInfo->h_length);
-
-    	/* fill address struct */
-    	Address.sin_addr.s_addr=nHostAddress;
-    	Address.sin_port=htons(port);
-    	Address.sin_family=AF_INET;
-
-    	printf("\nConnecting to %s on port %d",strHostName,port);
-
-    	/* connect to host */
-	
-
-    	if(connect(communicationdata->connectionlist[communicationdata->noconnections].sockethandle,(struct sockaddr*)&Address,sizeof(Address))== SOCKET_ERROR)
-    	{
-        	printf("\nCould not connect to host\n");
-        	return 0;
-    	}
-
- 	FD_SET(communicationdata->connectionlist[communicationdata->noconnections].sockethandle, &communicationdata->master);
-	communicationdata->fdmax = communicationdata->connectionlist[communicationdata->noconnections].sockethandle;
-	rc = pthread_create(&threadid, NULL, serverthread, NULL);
-	communicationdata->connected=1;
-	communicationdata->noconnections++;
-	return 1;
-}
-int communication_send_data(int id, char *message, int size, ip_communication* communicationdata)
-{
-	gint32 messagesize;
-	gint32 nomessages;
-	int i, location;
-	char* data;
-
-	nomessages=size/(BUFFER_SIZE-2*sizeof(gint32)); //Send in chunks of BUFFER_SIZE bytes
-	if(size%(BUFFER_SIZE-2*sizeof(int))!=0)
-		nomessages++;
-	printf("Sending %d messages.\n",nomessages);
-	location=0;
-	for (i=0;i<nomessages;i++)
-	{
-		if(location+(BUFFER_SIZE-2*sizeof(gint32))>size)
-			messagesize=size-location+2*sizeof(gint32);
-		else
-			messagesize=BUFFER_SIZE;
-			
-		data=(char *)malloc(messagesize);
-		memcpy(data,&messagesize,sizeof(gint32));
-		memcpy(data+sizeof(gint32),&nomessages,sizeof(gint32));
-		memcpy(data+2*sizeof(gint32),message+location,messagesize-2*sizeof(gint32));
-
-
-		if(communicationdata->connected)
-		{
-			printf("Sending %d bytes.",size);
-			write(communicationdata->connectionlist[id].sockethandle,data,messagesize);
-		}
-		else
-		{
-			printf("No connection available");
-			return -1;
-		}
-		free(data);
-	}
-	return nomessages;
-}
-
-
-int communication_start_server(int id, int port, ip_communication* communicationdata)
-{
-    struct hostent* pHostInfo;   /* holds info about a machine */
-    struct sockaddr_in Address; /* Internet socket address stuct */
-    int nAddressSize=sizeof(struct sockaddr_in);
-    int rc,i;
-    pthread_t threadid;
-
-    if(communicationdata->serverrunning==1)
-    {
-	printf("\nServer allready running\n");
-	return 0;
-    }
-
-    printf("\nStarting server");
-
-    FD_ZERO(&communicationdata->master);    // clear the master and temp sets
-    FD_ZERO(&communicationdata->read_fds);
-
-    printf("\nMaking socket");
-    /* make a socket */
-    communicationdata->hServerSocket=socket(AF_INET,SOCK_STREAM,0);
-
-    if(communicationdata->hServerSocket == SOCKET_ERROR)
-    {
-        printf("\nCould not make a socket\n");
-        return 0;
-    }
-
-    /* fill address struct */
-    Address.sin_addr.s_addr=INADDR_ANY;
-    Address.sin_port=htons(port);
-    Address.sin_family=AF_INET;
-
-    printf("\nBinding to port %d\n",port);
-
-    /* bind to a port */
-    if(bind(communicationdata->hServerSocket,(struct sockaddr*)&Address,sizeof(Address)) 
-                        == SOCKET_ERROR)
-    {
-        printf("\nCould not bind\n");
-        return 0;
-    }
- /*  get port number */
-    getsockname( communicationdata->hServerSocket, (struct sockaddr *) &Address,(socklen_t *)&nAddressSize);
-    printf("opened socket as fd (%d) on port (%d) for stream i/o\n",communicationdata->hServerSocket, ntohs(Address.sin_port) );
-
-        printf("Server\n\
-              sin_family        = %d\n\
-              sin_addr.s_addr   = %d\n\
-              sin_port          = %d\n"
-              , Address.sin_family
-              , Address.sin_addr.s_addr
-              , ntohs(Address.sin_port)
-            );
-     printf("\nMaking a listen queue of %d elements",QUEUE_SIZE);
-    /* establish listen queue */
-    if(listen(communicationdata->hServerSocket,QUEUE_SIZE) == SOCKET_ERROR)
-    {
-        printf("\nCould not listen\n");
-        return 0;
-    }
-
-    printf("\nWaiting for a connection\n");
-    FD_SET(communicationdata->hServerSocket, &communicationdata->master);     
-    communicationdata->fdmax = communicationdata->hServerSocket;
-     
-     communicationdata->connected=0;
-     communicationdata->serverrunning=1;
-     communicationdata->noconnections=0;
-     rc = pthread_create(&threadid, NULL, serverthread, (void *) communicationdata);//The listening thread is started     
-     return 1;
-   
-}
-
-void * serverthread(void * arg)//Communication thread, creates listening socket and listens to open sockets for incoming messages
-{
-	gint32 size,i;
-	int id=0;
-	char buffer[BUFFER_SIZE];
-	FILE *logfile;
-	char* packetinfo;
-	gint32 messagesize;
-	gint32 nomessages;
-	struct sockaddr_in Address; /* Internet socket address stuct */
-	int nAddressSize=sizeof(struct sockaddr_in);
-	ip_communication* communicationdata;
-
-	packetinfo=(char *)malloc(2*sizeof(int));
-	communicationdata=(ip_communication*)arg;
-
-
-	for(;;)
-    	{	
-		communicationdata->read_fds = communicationdata->master; // copy it
-		
-        	if (select(communicationdata->fdmax+1, &communicationdata->read_fds, NULL, NULL, NULL) == -1) {
-			if (errno != EINTR) {
-            			perror("select");
-            			exit(4);
-			}
-        	}
-		for(i = 0; i <= communicationdata->fdmax; i++) {
-			if (FD_ISSET(i, &communicationdata->read_fds)) {
-				if (i == communicationdata->hServerSocket) {//New connection
-					communicationdata->connectionlist = (struct connection *)realloc(communicationdata->connectionlist, (communicationdata->noconnections+1) * sizeof(struct connection));
-
-					communicationdata->connectionlist[communicationdata->noconnections].sockethandle=accept(communicationdata->hServerSocket,(struct sockaddr*)&Address,(socklen_t *)&nAddressSize);
-
-				     	printf("\nGot a connection");   
-				     	printf("Server\n\
-					      sin_family        = %d\n\
-					      sin_addr.s_addr   = %d\n\
-					      sin_port          = %d\n"
-					      , Address.sin_family
-					      , Address.sin_addr.s_addr
-					      , ntohs(Address.sin_port)
-					    );  
-				     	communicationdata->connectionlist[communicationdata->noconnections].userid=id;
-
-				     	FD_SET(communicationdata->connectionlist[communicationdata->noconnections].sockethandle, &communicationdata->master);     
-				     	communicationdata->fdmax = communicationdata->connectionlist[communicationdata->noconnections].sockethandle;
-				     	communicationdata->connected=1;
-					communicationdata->noconnections++;
-				}
-				else //incoming data
-				{
-					int j;
-					//What connections is sending?
-					while(j<communicationdata->noconnections)
-					{
-						if (i == communicationdata->connectionlist[j].sockethandle)
-						break;
-					}					
-
-
-					// read packetinfo 
-					size=read(communicationdata->connectionlist[j].sockethandle,packetinfo,2*sizeof(gint32));
-					memcpy(&messagesize,packetinfo,sizeof(gint32));
-					memcpy(&nomessages,packetinfo+sizeof(gint32),sizeof(gint32));
-					printf("\nReceived %d bytes. Messagesize: %d, NoMessages: %d",size,messagesize,nomessages);
-
-					size=read(communicationdata->connectionlist[j].sockethandle,buffer,BUFFER_SIZE);
-					printf("\nReceived %d bytes.",size);
-					if(size<=0)//connection breaks
-					{
-						printf("\nLost connection.");
-						communication_close_connection();
-					}
-					collaboration_handle_message(buffer,size,id);
-		
-				}
-			}
-
-
-		}
-
-		
-	}
-}
-
-int communication_close_connection(int id, ip_communication* communicationdata)
-{
-	printf("\nClosing socket\n");
-    	/* close socket */                       
-    	if(close(communicationdata->connectionlist[id].sockethandle) == SOCKET_ERROR)
-    	{
-        	printf("\nCould not close socket\n");
-		exit(-1);
-    	}
-	communicationdata->noconnections--;
-	if(communicationdata->noconnections==0)
-		communicationdata->connected=0;
-	
-	return 1;
-}
 
 gems_communication_data* gems_communication_init()
 {
@@ -599,106 +305,54 @@ gint gems_communication_request_groups()
 	gboolean cleanup_required = FALSE;
 	gems_connection* element = NULL;
 	gchar* logmsg = NULL;
-	
-	// TODO change to rely on the list we have?
-	// Get surrounding devices with service GROUP_SERVICE_NAME 
-	TDeviceList* list = ph_c_get_devicelist_with_services(data->ph,GROUP_SERVICE_NAME);
-	
-	// Got a NULL reference - error with PeerHood -> stop it
-	if(list == NULL)
-	{
-		logmsg = g_strdup_printf("gems_communication_request_groups: connection to PeerHood daemon was lost.");
-		cem_add_to_log(logmsg, LOG_NETWORK_DEBUG);
-		g_free(logmsg);
-		gems_communication_peerhood_close_detected();
-		return FALSE;
-	}
-	
-	if(ph_c_devicelist_is_empty(list) == FALSE)
-	{
-		// Initialize wrapper for iterator for list
-		DeviceIterator* iterator = NULL;
-
-		if(iterator == NULL)
-		{
-			ph_c_delete_devicelist(list);
-			return TRUE;
-		}
 		
+	// List exists
+	if (data->communication->connections != NULL)	
+	{
+		GList* iter = NULL;
 		// Go through list
-		for(iterator = ph_c_new_device_iterator(list); ph_c_device_iterator_is_last(iterator,list) != TRUE; ph_c_device_iterator_next_iterator(iterator))
+		for(iter = g_list_first(data->communication->connections); iter; iter = g_list_next(iter))
 		{
-			// Get the device
-			MAbstractDevice* dev = ph_c_device_iterator_get_device(iterator);
-			
-			// Through WLAN and has peerhood? - all devices in the list should have ph enabled
-			if((strcmp(ph_c_device_get_prototype(dev),"wlan-base") == 0) && (ph_c_device_has_peerhood(dev) == TRUE))
+			element = (gems_connection*)iter->data;
+
+			if(element != NULL)
 			{
-				switch(gems_communication_already_connected(ph_c_device_get_checksum(dev)))
+				// Connected and authenticated & profile is requested
+				if(element->connection_state == JAMMO_CONNECTED_AUTH && element->profile != NULL)
 				{
-					// Not connected ?
-					case NOT_IN_LIST:
-						// Try to establish connection
-						if(gems_communication_establish_connection(dev) == TRUE)
+					// Do not send the request to group members
+					if(gems_group_is_in_group(element->profile->id) == FALSE)
+					{
+						// Request already done -> timer should have been set
+						if(g_timer_elapsed(element->group_request_timer,NULL) < GROUP_REQUEST_INTERVAL) continue;
+
+						//printf("gems_communication_request_groups: sending REQUEST_GROUP_INFO (%f)",g_timer_elapsed(element->group_request_timer,NULL));
+
+						gems_message* request = gems_create_message_group_management_notify(REQUEST_GROUP_INFO,0,0);
+
+						if(gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE, element, request) == FALSE)
 						{
-							logmsg = g_strdup_printf("gems_communication_request_groups: Connected to new JamMo enabled device %s/%d",
-								ph_c_device_get_name(dev),ph_c_device_get_checksum(dev));
-							cem_add_to_log(logmsg, LOG_NETWORK_DEBUG);
+							logmsg = g_strdup_printf("gems_communication_request_groups: cannot write REQUEST_GROUP_INFO");
+							cem_add_to_log(logmsg, LOG_ERROR);
 							g_free(logmsg);
+							ph_c_connection_disconnect(element->connection);
+							cleanup_required = TRUE;
 						}
-						break;
-					case IN_CONNECTED_LIST:
-						element = gems_communication_get_connection(data->communication->connections, ph_c_device_get_checksum(dev));
-
-						// If we're already connected we can send group request
-						if(element != NULL)
+						else
 						{
-							// Connected and authenticated & profile is requested
-							if(element->connection_state == JAMMO_CONNECTED_AUTH && element->profile != NULL)
-							{
-								// Do not send the request to group members
-								if(gems_group_is_in_group(element->profile->id) == FALSE)
-								{
-									// Request already done -> timer should have been set
-									if(g_timer_elapsed(element->group_request_timer,NULL) < GROUP_REQUEST_INTERVAL) continue;
-
-									//printf("gems_communication_request_groups: sending REQUEST_GROUP_INFO (%f)",g_timer_elapsed(element->group_request_timer,NULL));
-
-									gems_message* request = gems_create_message_group_management_notify(REQUEST_GROUP_INFO,0,0);
-
-									if(gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE, element, request) == FALSE)
-									{
-										logmsg = g_strdup_printf("gems_communication_request_groups: cannot write REQUEST_GROUP_INFO");
-										cem_add_to_log(logmsg, LOG_ERROR);
-										g_free(logmsg);
-										ph_c_connection_disconnect(element->connection);
-										cleanup_required = TRUE;
-									}
-									else
-									{
-										/*printf("gems_communication_request_groups: wrote REQUEST_GROUP_INFO [%d|%d|%d]",
-											ntohs(*(gint16*)&request->message[0]),
-											ntohl(*(gint32*)&request->message[2]),
-											ntohs(*(gint16*)&request->message[6]));*/
-										g_timer_start(element->group_request_timer);
-									}
-
-									gems_clear_message(request);
-								}
-							}
+							/*printf("gems_communication_request_groups: wrote REQUEST_GROUP_INFO [%d|%d|%d]",
+								ntohs(*(gint16*)&request->message[0]),
+								ntohl(*(gint32*)&request->message[2]),
+								ntohs(*(gint16*)&request->message[6]));*/
+							g_timer_start(element->group_request_timer);
 						}
-						break;
-					default:
-						break;
-				} // switch
-			} // for
+
+						gems_clear_message(request);
+					}
+				}
+			}
 		}
-		
-		// Delete the iterator
-		ph_c_delete_device_iterator(iterator);
 	}
-	// Delete the list of devices
-	ph_c_delete_devicelist(list);
 	
 	if(cleanup_required == TRUE) data->communication->connections = gems_cleanup_connections_from_list(data->communication->connections);
 	
@@ -1390,6 +1044,21 @@ gboolean gems_communication_process_data(gems_connection* element)
 				success = FALSE; // TODO change to add a "invalid message" to errors
 			}
 			break;
+		case CONTROL_SERVICE_ID:
+			// Check that service is running
+			if(data->service_control->enabled == TRUE) success = gems_service_control_process_request(element);
+			else
+			{
+				err = gems_create_error_message(ERROR_SERVICE_NOT_RUNNING_TYPE, CONTROL_SERVICE_ID);
+				if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),err) != err->length)
+				{
+					logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_SERVICE_NOT_RUNNING");
+					cem_add_to_log(logmsg, LOG_ERROR);
+					g_free(logmsg);
+				}
+				gems_clear_message(err);
+				success = FALSE; // TODO change to add a "invalid message" to errors
+			}
 			
 			break;
 		/*case SONGBANK_SERVICE_ID:
