@@ -18,21 +18,11 @@
 #include "gems.h"
 #include "gems_service_profile.h"
 
+
 #include <netinet/in.h>
 
 
-
-typedef struct connection{
-	int userid;
-	struct sockaddr_in Address;  /* Internet socket address stuct */
-	int sockethandle;
-} connection;
-
 int communication_init();
-int communication_create_connection(char *address, int port, ip_communication* communicationdata);
-int communication_send_data(int id, char *message, int size, ip_communication* communicationdata);
-int communication_start_server(int id, int port, ip_communication* communicationdata);
-int communication_close_connection();
 int communication_list_users();
 
 gems_communication_data* gems_communication_init();
