@@ -16,22 +16,20 @@
 #include "messages.h"
 #include "messagehandler.h"
 #include "gems_message_functions.h"
-#include "gems_service_collaboration.h"
 #include "groupmanager.h"
 #include <glib.h>
 #include <arpa/inet.h>
 #include <string.h>
 
-static const char* myname = "Test User";//Default user name for testing
-
 static gems_components* gems_data = NULL;
 
 // empty callbacks for CHUM. These are used to avoid problems when calling an unset callback
 static void empty_callback_add_loop_to_slot(GObject * game, guint user_id, guint id, guint slot){}
 static void empty_callback_remove_loop_from_slot(GObject * game, guint user_id, guint slot){}
+static void empty_callback_loop_sync(GObject * game, guint user_id, GList * list){}
 static void empty_callback_midi_list(GObject * game, guint user_id, gint16 instrument_id, GemsEventListOperation operation, GList * list){}
 static void empty_callback_slider_event_list(GObject * game, guint user_id, gint16 instrument_id, GemsEventListOperation operation, GList * list){}
-static void empty_callback_group_control(gint type){}
+static void empty_callback_group_control(GObject * game, gint type){}
 
 // A "singleton" get
 gems_components* gems_get_data()
@@ -54,6 +52,63 @@ gems_components* gems_get_data()
 	return gems_data;
 }
 
+ProfileManager* gems_get_profile_manager()
+{
+	return gems_get_data()->pm;
+}
+
+MPeerHood* gems_get_peerhood()
+{
+	return gems_get_data()->ph;
+}
+
+gboolean gems_peerhood_enabled()
+{
+	return TRUE; // TODO add ph_on boolean
+}
+
+GList* gems_get_initialized_connections()
+{
+	return gems_get_data()->initialized_connections;
+}
+
+gems_communication_data* gems_get_communication()
+{
+	return gems_get_data()->communication;
+}
+
+gems_service_jammo* gems_get_service_jammo()
+{
+	return gems_get_data()->service_jammo;
+}
+
+// TODO when AA service is implemented
+/*gems_service_aa* gems_get_service_aa()
+{
+	return NULL; 
+}*/
+
+gems_service_profile* gems_get_service_profile()
+{
+	return gems_get_data()->service_profile;
+}
+
+gems_service_group* gems_get_service_group()
+{
+	return gems_get_data()->service_group;
+}
+
+gems_service_collaboration* gems_get_service_collaboration()
+{
+	return gems_get_data()->service_collaboration;
+}
+
+GList* gems_get_errorlist()
+{
+	return gems_get_data()->connection_errorlist;
+}
+
+
 void gems_free_data()
 {
 	if(gems_data)
@@ -72,7 +127,6 @@ void gems_free_data()
 void jammo_gems_init(int argc, char* argv[])
 {
 	gchar* logmsg = NULL;
-	gint serviceport = 0;
 	
 	// All components
 	gems_components* components = gems_get_data();
@@ -94,6 +148,9 @@ void jammo_gems_init(int argc, char* argv[])
 
 	// Initialize Collaboration service
 	components->service_collaboration = gems_service_collaboration_init();
+
+	// Initialize Control service
+	components->service_control = gems_service_control_init();
 	
 	// Define function pointers for notify and new connection functions
 	void (*notify)(short, const char*,void*) = NULL;
@@ -106,69 +163,7 @@ void jammo_gems_init(int argc, char* argv[])
 	components->ph_cb = ph_c_create_callback(notify, newconnection,(void*)components,(void*)components);
 	components->ph = ph_c_get_instance(components->ph_cb);
 	
-	if(ph_c_init(components->ph,argc,argv) == TRUE)
-	{
-		// Create JamMo service
-		if((serviceport = ph_c_register_service(components->ph,JAMMO_SERVICE_NAME,"application:jammo,method:versioncheck")) != 0)
-		{
-			components->service_jammo->enabled = TRUE; //enabled
-			components->service_jammo->port = serviceport;
-			logmsg = g_strdup_printf("jammo_gems_init: registered %s service.",JAMMO_SERVICE_NAME);
-		}
-		else
-		{
-			components->service_jammo->enabled = FALSE;
-			logmsg = g_strdup_printf("jammo_gems_init: cannot register %s service.",JAMMO_SERVICE_NAME);
-		}
-		cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
-		g_free(logmsg);
-		
-		// Create JamMo service
-		if((serviceport = ph_c_register_service(components->ph,PROFILE_SERVICE_NAME,"application:jammo,method:getprofile")) != 0)
-		{
-			components->service_profile->enabled = TRUE; //enabled
-			components->service_profile->port = serviceport;
-			logmsg = g_strdup_printf("jammo_gems_init: registered %s service.",PROFILE_SERVICE_NAME);
-		}
-		else
-		{
-			components->service_profile->enabled = FALSE;
-			logmsg = g_strdup_printf("jammo_gems_init: cannot register %s service.",PROFILE_SERVICE_NAME);
-		}
-		cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
-		g_free(logmsg);
-		
-		// Create JamMo service
-		if((serviceport = ph_c_register_service(components->ph,GROUP_SERVICE_NAME,"application:jammo,method:groupmanager")) != 0)
-		{
-			components->service_group->enabled = TRUE; //enabled
-			components->service_group->port = serviceport;
-			logmsg = g_strdup_printf("jammo_gems_init: registered %s service.",GROUP_SERVICE_NAME);
-		}
-		else
-		{
-			components->service_group->enabled = FALSE;
-			logmsg = g_strdup_printf("jammo_gems_init: cannot register %s service.",GROUP_SERVICE_NAME);
-		}
-		cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
-		g_free(logmsg);
-
-		// Create Collaboration service
-		if((serviceport = ph_c_register_service(components->ph,COLLABORATION_SERVICE_NAME,"application:jammo,method:collaboration")) != 0)
-		{
-			components->service_collaboration->enabled = TRUE; //enabled
-			components->service_collaboration->port = serviceport;
-			logmsg = g_strdup_printf("jammo_gems_init: registered %s service.",COLLABORATION_SERVICE_NAME);
-		}
-		else
-		{
-			components->service_collaboration->enabled = FALSE;
-			logmsg = g_strdup_printf("jammo_gems_init: cannot register %s service.",COLLABORATION_SERVICE_NAME);
-		}
-		cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
-		g_free(logmsg);
-
-	}
+	if(ph_c_init(components->ph,argc,argv) == TRUE) gems_register_services();
 	else
 	{
 		logmsg = g_strdup_printf("NO PEERHOOD RUNNING - NETWORKING DISABLED");
@@ -192,27 +187,11 @@ void jammo_gems_init(int argc, char* argv[])
 		//g_timeout_add_full(G_PRIORITY_LOW,2000,(GSourceFunc)gems_communication_probe_for_peerhood, NULL, NULL);
 	}
 	
-	components->ip_data = (ip_communication*)g_malloc(sizeof(ip_communication));
-	
-	
-	//set up default profile for testing TODO change to use profile manager with real profile
-	components->my_profile = (gems_peer_profile*)g_malloc(sizeof(gems_peer_profile));
-	components->my_profile->id=222;
-	components->my_profile->username=myname;
-	components->my_profile->avatarid=1;
-	components->my_profile->age=5;
-	
-	//Start ip communication TODO check preferences if it should be started
-	if (argc==4 && strcmp(argv[1],"--client")==0) {
-		collaboration_create_game_client(argv[2], atoi(argv[3]), components->ip_data);
-	}
-	else if (argc==3 && strcmp(argv[1],"--server")==0) {
-		collaboration_create_game_server(atoi(argv[2]), components->ip_data);
-	}
 
 	//Init CHUM Callbacks.
 	chum_callback_add_loop_to_slot=empty_callback_add_loop_to_slot;
 	chum_callback_remove_loop_from_slot=empty_callback_remove_loop_from_slot;
+	chum_callback_loop_sync=empty_callback_loop_sync;
 	chum_callback_midi_list=empty_callback_midi_list;
 	chum_callback_slider_event_list=empty_callback_slider_event_list;
 	chum_callback_group_control=empty_callback_group_control;
@@ -327,6 +306,10 @@ void gems_remove_sample_from_slot(guint slot)
 {
 	collaboration_remove_sample_from_slot(slot);
 }
+void gems_loop_sync(GList * list)
+{
+	collaboration_loop_sync(list);
+}
 void gems_midi_events_to_track(GemsEventListOperation operation, gint16 instrument_id, GList * list)
 {
 	collaboration_midi_events_to_track(operation, instrument_id, list);
@@ -334,9 +317,10 @@ void gems_midi_events_to_track(GemsEventListOperation operation, gint16 instrume
 void gems_slider_events_to_track(GemsEventListOperation operation, gint16 instrument_id, GList * list) {
 	collaboration_slider_events_to_track(operation, instrument_id, list);
 }
-void gems_start_pair_game()
+void gems_start_pair_game(gint16 theme, gint16 variation)
 {
-
+		gems_components* data = gems_get_data();
+		collaboration_start_pair_game(1, 1, data);
 }
 int gems_create_game_server(int port)
 {
@@ -356,7 +340,7 @@ GList* gems_list_jammo_connections()
 	gems_components* data = gems_get_data();
 	
 	if(data == NULL) return NULL;
-	
+	if(data->communication == NULL) return NULL;
 	if(data->communication->connections == NULL) return NULL;
 	else
 	{
@@ -769,6 +753,10 @@ void gems_set_callback_remove_loop(void (*func_ptr)(GObject * game, guint user_i
 	chum_callback_remove_loop_from_slot=func_ptr;
 }
 
+void gems_set_callback_loop_sync(void (*func_ptr)(GObject * game, guint user_id, GList * list) ) {
+	chum_callback_loop_sync=func_ptr;
+}
+
 void gems_set_callback_midi_list(void (*func_ptr)(GObject * game, guint user_id, gint16 instrument_id, GemsEventListOperation operation, GList * list) ) {
 	chum_callback_midi_list=func_ptr;
 }
@@ -776,7 +764,7 @@ void gems_set_callback_midi_list(void (*func_ptr)(GObject * game, guint user_id,
 void gems_set_callback_slider_event_list(void (*func_ptr)(GObject * game, guint user_id, gint16 instrument_id, GemsEventListOperation operation, GList * list) ) {
 	chum_callback_slider_event_list=func_ptr;
 }
-void gems_set_callback_group_control(void (*func_ptr)(gint type) ) {
+void gems_set_callback_group_control(void (*func_ptr)(GObject * game, gint type) ) {
 	chum_callback_group_control=func_ptr;
 }
 
@@ -897,6 +885,18 @@ void gems_register_services()
 		components->service_collaboration->enabled = FALSE;
 		logmsg = g_strdup_printf("gems_networking_register_services: cannot register %s service.",COLLABORATION_SERVICE_NAME);
 	}
+	// Create Control service
+	if((serviceport = ph_c_register_service(components->ph,CONTROL_SERVICE_NAME,"application:jammo,method:control")) != 0)
+	{
+		components->service_control->enabled = TRUE; //enabled
+		components->service_control->port = serviceport;
+		logmsg = g_strdup_printf("gems_networking_register_services: registered %s service.",CONTROL_SERVICE_NAME);
+	}
+	else
+	{
+		components->service_control->enabled = FALSE;
+		logmsg = g_strdup_printf("gems_networking_register_services: cannot register %s service.",CONTROL_SERVICE_NAME);
+	}
 	cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
 	g_free(logmsg);
 
