@@ -20,6 +20,7 @@
 
 #include "../meam/jammo-midi.h"
 #include "../meam/jammo-slider-event.h"
+#include "../meam/jammo-loop.h"
 
 gems_message* gems_create_error_message(gint16 errortype, gint16 serviceid)
 {	
@@ -557,6 +558,51 @@ gems_message* gems_create_message_collaboration_action_loop(gint16 type, guint l
 	return msg;
 }
 
+gems_message* gems_create_message_collaboration_action_loop_sync(GList * list)
+{
+	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));	
+	guint position = 0;
+
+	msg->length = sizeof(gint16) + sizeof(gint32) + sizeof(gint16) + sizeof(guint) + g_list_length(list) * (2*sizeof(guint32));
+	
+	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
+
+	
+	memset(msg->message,'\0',msg->length);
+
+	// Service id 16 bits
+	*(gint16*)&msg->message[position] = g_htons(COLLABORATION_SERVICE_ID);
+	position = position + sizeof(gint16);
+	
+	// Length 32 bits
+	*(gint32*)&msg->message[position] = g_htonl(msg->length);
+	position = position + sizeof(gint32);
+	
+	// Command 16 bits
+	*(gint16*)&msg->message[position] = g_htons(ACTION_LOOP_SYNC);
+	position = position + sizeof(gint16);
+
+	//TODO change USER ID to real value
+	// 32 bits
+	*(guint*)&msg->message[position] = g_htonl(0);
+	position = position + sizeof(guint);
+
+	// list, one loop is 8 bytes
+	GList * temp;
+	JammoLoop * loop;
+	for (temp=g_list_first(list);temp;temp=temp->next) {
+		loop = temp->data;
+		// loop id
+		*(guint32 *)&msg->message[position] = g_htonl(loop->loop_id);
+		position = position + sizeof(guint32);
+		// slot
+		*(guint32 *)&msg->message[position] = g_htonl(loop->slot);
+		position = position + sizeof(guint32);
+	}
+	
+	return msg;
+}
+
 gems_message* gems_create_message_collaboration_action_midi_series(gint16 type, gint16 instrument_id, GList * list)
 {
 	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));	
@@ -669,3 +715,61 @@ gems_message* gems_create_message_collaboration_action_slider_series(gint16 type
 	
 	return msg;
 }
+
+gems_message* gems_create_message_control_mode(gint16 type, gint16 cntrl_type, gint16 lock_mode)
+{
+	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));	
+	guint position = 0;
+
+	msg->length = sizeof(gint16) + sizeof(gint32) + sizeof(gint16) + sizeof(gint16) + sizeof(gint16);
+
+	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
+	memset(msg->message,'\0',msg->length);
+
+	// Service id 16 bits
+	*(gint16*)&msg->message[position] = g_htons(CONTROL_SERVICE_ID);
+	position = position + sizeof(gint16);
+	
+	// Length 32 bits
+	*(gint32*)&msg->message[position] = g_htonl(msg->length);
+	position = position + sizeof(gint32);
+	
+	// Command 16 bits
+	*(gint16*)&msg->message[position] = g_htons(CONTROL_MODE);
+	position = position + sizeof(gint16);
+
+	// Control type 16 bits
+	*(gint16*)&msg->message[position] = g_htons(cntrl_type);
+	position = position + sizeof(gint16);
+
+	// Lock mode 16 bits
+	*(gint16*)&msg->message[position] = g_htons(lock_mode);
+	position = position + sizeof(gint16);
+
+	return msg;
+}
+
+gems_message* gems_create_message_control_ok(gint16 type)
+{
+	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));	
+	guint position = 0;
+
+	msg->length = sizeof(gint16) + sizeof(gint32) + sizeof(gint16);
+
+	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
+	memset(msg->message,'\0',msg->length);
+
+	// Service id 16 bits
+	*(gint16*)&msg->message[position] = g_htons(CONTROL_SERVICE_ID);
+	position = position + sizeof(gint16);
+	
+	// Length 32 bits
+	*(gint32*)&msg->message[position] = g_htonl(msg->length);
+	position = position + sizeof(gint32);
+	
+	// Command 16 bits
+	*(gint16*)&msg->message[position] = g_htons(CONTROL_OK);
+	position = position + sizeof(gint16);
+
+	return msg;
+}
