@@ -33,6 +33,7 @@ gint gems_service_jammo_process_connections()
 {	
 	gems_components* data = gems_get_data();
 	if(data == NULL) return FALSE;
+	if(data->ph == NULL) return FALSE;
 	if(data->service_jammo->enabled == FALSE) return FALSE;
 	
 	data->service_jammo->connections = gems_service_jammo_process_list(data->service_jammo->connections, TRUE);
@@ -628,15 +629,22 @@ void gems_service_jammo_cleanup()
 	cem_add_to_log(logmsg,LOG_DEBUG);
 	g_free(logmsg);
 	
-	if(data->connections != NULL)
-	{
-		g_list_foreach(data->connections,(GFunc)gems_clear_gems_connection,NULL);
-		g_list_free(data->connections);
-		data->connections = NULL;
-	}
+	gems_service_jammo_cleanup_lists();
 	
 	data->enabled = FALSE;
 	g_free(data);
 	data = NULL;
 }
 
+void gems_service_jammo_cleanup_lists()
+{
+	gems_service_jammo* data = gems_get_data()->service_jammo;
+
+	if(data->connections != NULL)
+	{
+		g_list_foreach(data->connections,(GFunc)gems_clear_gems_connection,NULL);
+		g_list_free(data->connections);
+		data->connections = NULL;
+	}
+}
+
