@@ -251,6 +251,7 @@ src->wav_based_instrument[index]->releasecounter=-1.0;
 src->wav_based_instrument[index]->fade_out=fade_out;
 
 SF_INFO sfinfo;
+sfinfo.format = 0;
 SNDFILE * sndfileptr = sf_open(filename, SFM_READ, &sfinfo);
 if (sndfileptr==NULL) {
 	printf("error opening file %s\n", filename);
@@ -741,7 +742,19 @@ static void do_playback_process(GstJammoSampler * src){
 		printf("DEBUG: gstjammosampler: delayed: %llu ms\n",(unsigned long long) (src->time - timestamp)/1000/1000);
 		int note=event->note;
 
-		if (event->type==0 && note>-1 && note < JAMMOMIDI_NUMBER_OF_NOTES) { //start  NOTE_ON
+		//note is unsigned.
+		//We can use sign to tell type of note. ON= +, OFF= -
+		int sign = event->type==JAMMOMIDI_NOTE_ON? 1:-1;
+		//printf("note %d, sign %d\n",note,sign);
+
+		//Report for visualization
+		GstStructure *s;\
+		s = gst_structure_new ("sampler", "note", G_TYPE_INT, sign * note, NULL);
+		GstMessage *m = gst_message_new_element (GST_OBJECT (src), s);
+		gst_element_post_message (GST_ELEMENT (src), m);
+
+
+		if (event->type==JAMMOMIDI_NOTE_ON && note>-1 && note < JAMMOMIDI_NUMBER_OF_NOTES) {
 			// if the note was not playing increment the number of playing notes
 			if (src->note_table[note]==FALSE)
 				src->notes_playing++;
@@ -760,7 +773,7 @@ static void do_playback_process(GstJammoSampler * src){
 			}
 		}
 
-		else if (event->type==1&& note>-1 && note < JAMMOMIDI_NUMBER_OF_NOTES) { //stop  NOTE_OFF
+		else if (event->type==JAMMOMIDI_NOTE_OFF && note>-1 && note < JAMMOMIDI_NUMBER_OF_NOTES) {
 			// release note only, the number of notes will be decreased when the note has faded
 			src->wav_based_instrument[note]->released=TRUE;
 		}
@@ -926,6 +939,7 @@ static gboolean gst_jammo_sampler_start (GstBaseSrc * basesrc)
   src->check_seek_stop = FALSE;
   src->eos_reached = FALSE;
   src->tags_pushed = FALSE;
+  src->time = 0;
   for (i=0; i<JAMMOMIDI_NUMBER_OF_NOTES;i++)
        src->accumulators[i] = 0;
 
@@ -951,7 +965,8 @@ static gboolean gst_jammo_sampler_start (GstBaseSrc * basesrc)
 
    for (list = src->eventlist; list; list = list->next) {
       n = (list->data);
-      printf("TEST:gstjammosampler:In stack: %llu ms: note:%d ,type: %s \n", (unsigned long long)n->timestamp/1000/1000,n->note,n->type==0? "start":"stop");
+      printf("TEST:gstjammosampler:In stack: %llu ms: note:%d ,type: %s \n", (unsigned long long)n->timestamp/1000/1000
+            ,n->note,n->type==JAMMOMIDI_NOTE_ON? "start":"stop");
    }
   }
 
