@@ -191,7 +191,7 @@ short karplus_strong (short x, gfloat length) {
   a = (long)x + interpolation(length-(int)length, y[((gint)(n - length)) & BITMASK],y[((gint)(n - (length+1))) & BITMASK]); /* interpolation */
 
   //b = ((a + ap) * 127) >> 8;            /* Coeff = +0.49609375. */
-    b = ((a + ap) * 127) / (254+length*0.01); //higher coeff on lower tones
+    b = ((a + ap) * 127) / (255);
     ap = a;                               /* Remember. */
     y[n++ & BITMASK] = (short)b;          /* Write in buffer. */
     return (short)b;
@@ -327,6 +327,7 @@ static void gst_jammo_slider_init (GstJammoSlider * src, GstJammoSliderClass * g
 
 	src->last_event_processed=FALSE;
 	src->time=0;
+	src->last_reported_frequency = -1;
 
   src->attack  = DEFAULT_ATTACK;
   src->decay   = DEFAULT_DECAY;
@@ -536,6 +537,31 @@ static gfloat freq_of_note[] = { 32.703201293945312, 34.647899627685547, 36.7080
  4186.009765625000000, 4434.931152343750000, 4698.636718750000000, 4978.035156250000000, 5274.047851562500000, 5587.660644531250000, 5919.910156250000000, 6271.936035156250000, 6644.863769531250000, 7040.000000000000000, 7458.624023437500000, 7902.131347656250000
 };
 
+static gfloat freq_of_quarter_tone[] = { 32.703201, 33.661480, 34.647835, 35.663094, 36.708103, 37.783733,
+38.890881, 40.030468, 41.203453, 42.410805, 43.653538, 44.932682, 46.249310, 47.604519, 48.999439, 50.435230,
+51.913097, 53.434265, 55.000008, 56.611633, 58.270481, 59.977936, 61.735424, 63.544411, 65.406403, 67.322960,
+69.295670, 71.326187, 73.416206, 75.567467, 77.781761, 80.060936, 82.406906, 84.821609, 87.307076, 89.865364,
+92.498619, 95.209038, 97.998878, 100.870461, 103.826195, 106.868530, 110.000015, 113.223267, 116.540962,
+119.955872, 123.470848, 127.088821, 130.812805, 134.645920, 138.591339, 142.652374, 146.832413, 151.134933,
+155.563522, 160.121872, 164.813812, 169.643219, 174.614151, 179.730728, 184.997238, 190.418076, 195.997757,
+201.740921, 207.652390, 213.737061, 220.000031, 226.446533, 233.081924, 239.911743, 246.941696, 254.177643,
+261.625610, 269.291840, 277.182678, 285.304749, 293.664825, 302.269867, 311.127045, 320.243744, 329.627625,
+339.286438, 349.228302, 359.461456, 369.994476, 380.836151, 391.995514, 403.481842, 415.304779, 427.474121,
+440.000061, 452.893066, 466.163849, 479.823486, 493.883392, 508.355286, 523.251221, 538.583679, 554.365356,
+570.609497, 587.329651, 604.539734, 622.254089, 640.487488, 659.255249, 678.572876, 698.456604, 718.922913,
+739.988953, 761.672302, 783.991028, 806.963684, 830.609558, 854.948242, 880.000122, 905.786133, 932.327698,
+959.646973, 987.766785, 1016.710571, 1046.502441, 1077.167358, 1108.730713, 1141.218994, 1174.659302,
+1209.079468, 1244.508179, 1280.974976, 1318.510498, 1357.145752, 1396.913208, 1437.845825, 1479.977905,
+1523.344604, 1567.982056, 1613.927368, 1661.219116, 1709.896484, 1760.000244, 1811.572266, 1864.655396,
+1919.293945, 1975.533569, 2033.421143, 2093.004883, 2154.334717, 2217.461426, 2282.437988, 2349.318604,
+2418.158936, 2489.016357, 2561.949951, 2637.020996, 2714.291504, 2793.826416, 2875.691650, 2959.955811,
+3046.689209, 3135.964111, 3227.854736, 3322.438232, 3419.792969, 3520.000488, 3623.144531, 3729.310791,
+3838.587891, 3951.067139, 4066.842285, 4186.009766, 4308.669434, 4434.922852, 4564.875977, 4698.637207,
+4836.317871, 4978.032715, 5123.899902, 5274.041992, 5428.583008, 5587.652832, 5751.383301, 5919.911621,
+6093.378418, 6271.928223, 6455.709473, 6644.876465, 6839.585938, 7040.000977, 7246.289062, 7458.621582,
+7677.175781, 7902.134277
+};
+
 /*We roll over above frequence table (sorted) and when value from table is bigger
 than parameter, we check which one is nearer (which direction to round)*/
 static gfloat freq_rounding(gfloat freq){
@@ -550,6 +576,20 @@ static gfloat freq_rounding(gfloat freq){
  return 8000; //We could also return biggest value from table.
 }
 
+/* similar rounding for new notes */
+/* this is done instantly. rounding to nearest quarter tone */
+static gfloat freq_rounding_new_note(gfloat freq){
+ int i; //i starts from 1. All too low values are then rounded to table[0]
+ for (i=1;i<NUMBER_OF_OCTAVES*NUMBER_OF_NOTES*2-1;i++){//roll over frequence table above (they are sorted)
+  if (freq_of_quarter_tone[i]>freq){                //continue until table has bigger than parameter
+    gfloat delta  =freq_of_quarter_tone[i]-freq;    //this is delta of parameter and bigger value from table
+    gfloat delta2 =freq-freq_of_quarter_tone[i-1];  //this is delta of parameter and smaller value from table
+    return delta<delta2?freq_of_quarter_tone[i]:freq_of_quarter_tone[i-1]; //return value, which is nearer to parameter
+  }
+ }
+ return 8000; //We could also return biggest value from table.
+}
+
 // a function for initializing parameters when starting to play a new note
 void process_slider_event_on(GstJammoSlider * src, float freq) {
 	src->state=TRUE;
@@ -562,7 +602,10 @@ void process_slider_event_on(GstJammoSlider * src, float freq) {
 	src->rounded=FALSE;
 	src->rounding_counter=0;
 	// sliding to a new note is not wanted
-	src->freq_slow=freq;
+	// but new notes have to be rounded to nearest quarter tone
+	// note that this rounding is done to audio only. events in stored list are not rounded in list
+	// all new on events (including playback from stored list) are rounded during playback
+	src->freq_slow=freq_rounding_new_note(freq);
 }
 
 void process_slider_event_off(GstJammoSlider * src, float freq) {
@@ -773,6 +816,15 @@ static void gst_jammo_slider_process_##type (GstJammoSlider * src, g##type * sam
 		}\
 	  samples[i]=value;\
 	} /* end process whole buffer */ \
+	\
+	if (src->freq!=src->last_reported_frequency) {\
+		src->last_reported_frequency=src->freq; \
+		GstStructure *s;\
+		s = gst_structure_new ("slider", "frequency", G_TYPE_FLOAT, src->freq, NULL);\
+\
+		GstMessage *m = gst_message_new_element (GST_OBJECT (src), s);\
+		gst_element_post_message (GST_ELEMENT (src), m);\
+	}\
 }
 
 DEFINE_PROCESS (int16, 32767.0);
@@ -1097,7 +1149,7 @@ static void gst_jammo_slider_set_property (GObject * object, guint prop_id,
 
 			//realtime. There are no timestamp in event, use current time
 			if (src->recording){
-				printf("realtime\n");
+				//printf("realtime\n");
 				timestamp = src->time;
 
 				if (event->type==JAMMO_SLIDER_EVENT_ON) {
