@@ -41,6 +41,14 @@ struct _JammoInstrumentTrackPrivate {
 	int instrument_type;
 };
 
+
+enum {
+	REPORT_NOTE,
+	LAST_SIGNAL
+};
+static guint signals[LAST_SIGNAL];
+
+
 JammoInstrumentTrack* jammo_instrument_track_new(JammoInstrumentType instrument_type) {
 	return JAMMO_INSTRUMENT_TRACK(g_object_new(JAMMO_TYPE_INSTRUMENT_TRACK,"instrument-type",instrument_type,NULL));
 }
@@ -104,6 +112,19 @@ static void jammo_instrument_track_dispose(GObject* object) {
 	G_OBJECT_CLASS(jammo_instrument_track_parent_class)->dispose(object);
 }
 
+static void jammo_instrument_track_receive_message(JammoTrack* track, GstMessage* message) {
+	const GstStructure* structure;
+	gint note;
+
+
+	structure = gst_message_get_structure(message);
+	if (structure && !strcmp(gst_structure_get_name(structure), "sampler")) {
+		note = g_value_get_int(gst_structure_get_value(structure, "note"));
+		//printf("jammo-instrument-track: receive_note %d\n",note);
+		g_signal_emit(track, signals[REPORT_NOTE], 0, note);
+	}
+}
+
 static GObject* jammo_instrument_track_constructor(GType type, guint n_properties, GObjectConstructParam* properties) {
 	GObject* object;
 	JammoInstrumentTrack* instrument_track;
@@ -164,6 +185,8 @@ static void jammo_instrument_track_class_init(JammoInstrumentTrackClass* instrum
 	gobject_class->set_property = jammo_instrument_track_set_property;
 	gobject_class->get_property = jammo_instrument_track_get_property;
 
+	track_class->receive_message = jammo_instrument_track_receive_message;
+
 	/**
 	 * JammoInstrumentTrack:instrument-type:
 	 */
@@ -173,7 +196,14 @@ static void jammo_instrument_track_class_init(JammoInstrumentTrackClass* instrum
 	                                "Specifies type of instrument",
 	                                0,JAMMO_INSTRUMENT_TYPE_DUMMY-1,0,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	
+
+	signals[REPORT_NOTE] = g_signal_new("report-note", G_TYPE_FROM_CLASS(gobject_class),
+	                                    G_SIGNAL_RUN_LAST, 0,
+	                                    NULL, NULL,
+	                                    g_cclosure_marshal_VOID__INT,
+	                                    G_TYPE_NONE, 1,
+	                                    G_TYPE_INT);
+
 	g_type_class_add_private(gobject_class, sizeof(JammoInstrumentTrackPrivate));
 }
 
